@@ -57,6 +57,8 @@ from ubuntuone.syncdaemon import (
     main,
     local_rescan,
     tritcask,
+    RECENT_TRANSFERS,
+    UPLOADING,
 )
 from ubuntuone.syncdaemon import logger
 from ubuntuone import platform
@@ -122,8 +124,12 @@ class FakeMark(object):
 class FakeExternalInterface(object):
     """A fake DBusInterface..."""
 
+    def start(self):
+        """... that knows how to start."""
+        return defer.succeed(None)
+
     def shutdown(self, with_restart=False):
-        """...that only knows how to go away"""
+        """... how to go away"""
 
     def _request_token(self, *args, **kwargs):
         """Return a token which is a fixed set of credentials."""
@@ -193,7 +199,7 @@ class FakeActionQueue(object):
 
     cancel_download = cancel_upload = download = upload = make_dir = disconnect
     make_file = move = unlink = list_shares = disconnect
-    list_volumes = create_share = create_udf = inquire_free_space =  disconnect
+    list_volumes = create_share = create_udf = inquire_free_space = disconnect
     inquire_account_info = delete_volume = change_public_access = disconnect
     query_volumes = get_delta = rescan_from_scratch = delete_share = disconnect
     node_is_with_queued_move = cleanup = get_public_files = disconnect
@@ -204,6 +210,10 @@ class FakeStatusListener(object):
 
     show_all_notifications = True
 
+    def menu_data(self):
+        """Fake menu_data."""
+        return {RECENT_TRANSFERS: [], UPLOADING: []}
+
 
 class FakeMain(main.Main):
     """ A fake Main class to setup the tests """
@@ -298,7 +308,7 @@ class BaseTwistedTestCase(TwistedTestCase):
         mmtree(path): support read-only shares
         makedirs(path): support read-only shares
     """
-    MAX_FILENAME = 32 # some platforms limit lengths of filenames
+    MAX_FILENAME = 32  # some platforms limit lengths of filenames
     tunnel_runner_class = FakeTunnelRunner
 
     def mktemp(self, name='temp'):
@@ -381,6 +391,11 @@ class BaseTwistedTestCase(TwistedTestCase):
     def setUp(self):
         yield super(BaseTwistedTestCase, self).setUp()
         self.__root = None
+
+        # Patch the user home
+        self.home_dir = self.mktemp('ubuntuonehacker')
+        self.patch(platform, "user_home", self.home_dir)
+
         # use the config from the branch
         new_get_config_files = lambda: [os.path.join(os.environ['ROOTDIR'],
                                                    'data', 'syncdaemon.conf')]
@@ -401,9 +416,6 @@ class BaseTwistedTestCase(TwistedTestCase):
         self.log = logging.getLogger("ubuntuone.SyncDaemon.TEST")
         self.log.info("starting test %s.%s", self.__class__.__name__,
                       self._testMethodName)
-        # Patch the user home
-        self.home_dir = self.mktemp('ubuntuonehacker')
-        self.patch(platform, "xdg_home", self.home_dir)
         self.patch(action_queue.tunnel_runner, "TunnelRunner",
                    self.tunnel_runner_class)
 
@@ -444,7 +456,7 @@ class FakeVolumeManager(object):
     def __init__(self, root_path):
         """ Creates the instance"""
         self.root = volume_manager.Root(node_id="root_node_id", path=root_path)
-        self.shares = {'':self.root}
+        self.shares = {'': self.root}
         self.udfs = {}
         self.log = logging.getLogger('ubuntuone.SyncDaemon.VM-test')
 
@@ -682,3 +694,7 @@ skip_if_win32_and_uses_readonly = \
 skip_if_win32_missing_fs_event = \
     skipIfOS('win32', 'Fails due to missing/out of order FS events, '
                       'see bug #820598.')
+
+skip_if_darwin_missing_fs_event = \
+    skipIfOS('darwin', 'Fails due to missing/out of order FS events, '
+                      'see bug #820598.')
