@@ -42,7 +42,7 @@ from twisted.internet import defer
 from zeitgeist.client import ZeitgeistClient
 from zeitgeist.datamodel import Event, Subject, Interpretation, Manifestation
 
-from tests.platform.linux.test_dbus import DBusTwistedTestCase
+from tests.platform.ipc.test_linux import DBusTwistedTestCase
 from ubuntuone.eventlog.zglog import ZeitgeistLogger
 
 SRCDIR = os.environ.get('SRCDIR', os.getcwd())
@@ -97,7 +97,7 @@ def wait_zeitgeist_started(seconds=10):
             client = ZeitgeistClient()
             break
         except RuntimeError:
-            if count > seconds*10:
+            if count > seconds * 10:
                 raise
             time.sleep(0.1)
 
@@ -118,6 +118,7 @@ class ZeitgeistTestCase(DBusTwistedTestCase):
         os.environ["ZEITGEIST_DATA_PATH"] = tempfolder
         p = subprocess.Popen([zgdaemon], bufsize=4096, stdout=tempstdout,
                              stderr=tempstderr)
+
         def cleanup():
             """Wait for the process to finish."""
             p.terminate()
