@@ -36,12 +36,15 @@ from twisted.internet import defer, reactor
 from ubuntuone.devtools.handlers import MementoHandler
 
 from contrib.testing.testcase import FakeCommand, skipIfOS
+
 from ubuntuone.syncdaemon import (
     action_queue,
     event_queue,
     interaction_interfaces,
     states,
     volume_manager,
+    RECENT_TRANSFERS,
+    UPLOADING,
 )
 from ubuntuone.platform import tools
 from tests.platform import IPCTestCase
@@ -243,6 +246,13 @@ class TestToolsBasic(TestToolsBase):
         self.assertEqual('share_id', result['volume_id'])
         self.assertEqual(False, self.main.vm.shares['share_id'].accepted)
 
+    @defer.inlineCallbacks
+    def test_sync_menu(self):
+        """Test accept_share method."""
+        result = yield self.tool.sync_menu()
+        self.assertIn(RECENT_TRANSFERS, result)
+        self.assertIn(UPLOADING, result)
+
 
 class TestWaitForSignals(TestToolsBase):
     """Test case for the wait_for_signals method from SyncDaemonTool."""
@@ -690,6 +700,36 @@ class TestToolsSomeMore(TestToolsBase):
         self.assertEqual('True', file_info['is_public'])
         self.assertEqual('http://example.com', file_info['public_url'])
 
+    @defer.inlineCallbacks
+    def test_change_public_access_with_unicode(self):
+        """Test change_public_access."""
+        # XXX: change public access is the only class that expects uuid's as
+        # params this may indicate that we need to refactor that class to be
+        # consistent with the rest of syncdaemon where ID's are always strings
+        node_id = '59809aae-9c5a-47e0-b37c-5abbfbe7c50a'
+        share_id = ""
+        path = os.path.join(self.root_dir, u"ñoño")
+        path = path.encode('utf-8')
+        self.fs.create(path, "")
+        self.fs.set_node_id(path, node_id)
+
+        def change_public_access(share_id, node_id, is_public):
+            """Fake change_public_access"""
+            self.main.event_q.push("AQ_CHANGE_PUBLIC_ACCESS_OK",
+                                   share_id=share_id, node_id=node_id,
+                                   is_public=True,
+                                   public_url='http://example.com')
+        self.patch(self.main.action_q, 'change_public_access',
+                   change_public_access)
+
+        file_info = yield self.tool.change_public_access(path, True)
+
+        self.assertEqual(path.decode('utf-8'), file_info['path'])
+        self.assertEqual(share_id, file_info['share_id'])
+        self.assertEqual(node_id, file_info['node_id'])
+        self.assertEqual('True', file_info['is_public'])
+        self.assertEqual('http://example.com', file_info['public_url'])
+
     @defer.inlineCallbacks
     def test_get_public_files(self):
         """Get the public files."""
