@@ -39,10 +39,15 @@ from mocker import Mocker
 
 from contrib.testing.testcase import BaseTwistedTestCase
 from ubuntuone.devtools.handlers import MementoHandler
+from ubuntuone.devtools.testcases import skipTest
 from ubuntuone.status import aggregator
 from ubuntuone.status.notification import AbstractNotification
 from ubuntuone.status.messaging import AbstractMessaging
-from ubuntuone.syncdaemon import status_listener
+from ubuntuone.syncdaemon import (
+    status_listener,
+    RECENT_TRANSFERS,
+    UPLOADING,
+)
 from ubuntuone.syncdaemon.volume_manager import Share, UDF, Root
 
 FILENAME = 'example.txt'
@@ -572,7 +577,6 @@ class ProgressBarTestCase(TestCase):
         """Initialize this test instance."""
         yield super(ProgressBarTestCase, self).setUp()
         self.patch(aggregator, "UbuntuOneLauncher", FakeLauncher)
-        self.patch(aggregator.session, "Inhibitor", FakeInhibitor)
         self.clock = PatchedClock()
         self.bar = aggregator.ProgressBar(clock=self.clock)
         self.addCleanup(self.bar.cleanup)
@@ -658,6 +662,7 @@ class ProgressBarTestCase(TestCase):
         self.assertFalse(self.bar.visible)
         self.assertFalse(self.bar.launcher.progress_visible)
 
+    @skipTest('Inhibitor is disabled to prevent bug #737620')
     @defer.inlineCallbacks
     def test_progress_made_inhibits_logout_suspend(self):
         """Suspend and logout are inhibited when the progressbar is shown."""
@@ -666,6 +671,7 @@ class ProgressBarTestCase(TestCase):
         inhibitor = yield self.bar.inhibitor_defer
         self.assertEqual(inhibitor.flags, expected)
 
+    @skipTest('Inhibitor is disabled to prevent bug #737620')
     @defer.inlineCallbacks
     def test_completed_uninhibits_logout_suspend(self):
         """Suspend and logout are uninhibited when all has completed."""
@@ -706,6 +712,8 @@ class FakeCommand(object):
         self.share_id = path
         self.node_id = path
         self.deflated_size = 10000
+        self.size = 0
+        self.n_bytes_written = 0
 
 
 class FakeVolumeManager(object):
@@ -733,6 +741,7 @@ class FakeAggregator(object):
         self.files_uploading = []
         self.files_downloading = []
         self.progress_events = []
+        self.recent_transfers = aggregator.deque(maxlen=10)
 
     def queue_done(self):
         """The queue completed all operations."""
@@ -762,6 +771,7 @@ class FakeAggregator(object):
         """An upload just finished."""
         if command in self.files_uploading:
             self.files_uploading.remove(command)
+        self.recent_transfers.append(command.path)
         self.queued_commands.discard(command)
 
     def progress_made(self, share_id, node_id, n_bytes, deflated_size):
@@ -796,6 +806,70 @@ class StatusFrontendTestCase(BaseTwistedTestCase):
                                                        self.fakevm,
                                                        self.status_frontend)
 
+    def test_recent_transfers(self):
+        """Check that it generates a tuple with the recent transfers."""
+        self.patch(status_listener.action_queue, "Upload", FakeCommand)
+        fake_command = FakeCommand('path1')
+        self.listener.handle_SYS_QUEUE_ADDED(fake_command)
+        self.listener.handle_SYS_QUEUE_REMOVED(fake_command)
+        fake_command = FakeCommand('path2')
+        self.listener.handle_SYS_QUEUE_ADDED(fake_command)
+        self.listener.handle_SYS_QUEUE_REMOVED(fake_command)
+        fake_command = FakeCommand('path3')
+        self.listener.handle_SYS_QUEUE_ADDED(fake_command)
+        self.listener.handle_SYS_QUEUE_REMOVED(fake_command)
+        transfers = self.status_frontend.recent_transfers()
+        expected = ['path1', 'path2', 'path3']
+        self.assertEqual(transfers, expected)
+
+        menu_data = self.listener.menu_data()
+        self.assertEqual(menu_data,
+            {UPLOADING: [], RECENT_TRANSFERS: expected})
+
+    def test_file_uploading(self):
+        """Check that it returns a list with the path, size, and progress."""
+        fc = FakeCommand(path='testfile.txt')
+        fc.size = 200
+        self.status_frontend.upload_started(fc)
+        uploading = self.status_frontend.files_uploading()
+        expected = [('testfile.txt', 200, 0)]
+        self.assertEqual(uploading, expected)
+        menu_data = self.listener.menu_data()
+        self.assertEqual(menu_data,
+            {UPLOADING: expected, RECENT_TRANSFERS: []})
+
+        fc.size = 1000
+        fc.n_bytes_written = 200
+        fc2 = FakeCommand(path='testfile2.txt')
+        fc2.size = 2000
+        fc2.n_bytes_written = 450
+        self.status_frontend.upload_started(fc2)
+        uploading = self.status_frontend.files_uploading()
+        expected = [('testfile.txt', 1000, 200), ('testfile2.txt', 2000, 450)]
+        self.assertEqual(uploading, expected)
+
+        menu_data = self.listener.menu_data()
+        self.assertEqual(menu_data,
+            {UPLOADING: expected, RECENT_TRANSFERS: []})
+
+    def test_menu_data_full_response(self):
+        """Check that listener.menu_data returns both uploading and recent."""
+        self.patch(status_listener.action_queue, "Upload", FakeCommand)
+        fake_command = FakeCommand('path1')
+        self.listener.handle_SYS_QUEUE_ADDED(fake_command)
+        self.listener.handle_SYS_QUEUE_REMOVED(fake_command)
+        fc = FakeCommand(path='testfile.txt')
+        fc.size = 1000
+        fc.n_bytes_written = 200
+        self.status_frontend.upload_started(fc)
+        uploading = self.status_frontend.files_uploading()
+        transfers = self.status_frontend.recent_transfers()
+        expected = {UPLOADING: [('testfile.txt', 1000, 200)],
+            RECENT_TRANSFERS: ['path1']}
+
+        self.assertEqual(
+            {UPLOADING: uploading, RECENT_TRANSFERS: transfers}, expected)
+
     def test_file_published(self):
         """A file published event is processed."""
         share_id = "fake share id"
@@ -1219,7 +1293,6 @@ class StatusAggregatorTestCase(TestCase):
         self.patch(aggregator, "ToggleableNotification",
                    FakeNotificationSingleton())
         self.patch(aggregator, "UbuntuOneLauncher", FakeLauncher)
-        self.patch(aggregator.session, "Inhibitor", FakeInhibitor)
         clock = PatchedClock()
         self.status_frontend = aggregator.StatusFrontend(clock=clock)
         self.aggregator = self.status_frontend.aggregator
@@ -1242,6 +1315,21 @@ class StatusAggregatorTestCase(TestCase):
         self.assertEqual({}, self.aggregator.to_do)
         self.assertIdentical(None, self.aggregator.queue_done_timer)
 
+    def test_register_progress_listener(self):
+        """Check that register listener handles properly additions."""
+
+        def fake_callback():
+            """Do nothing."""
+
+        self.aggregator.register_progress_listener(fake_callback)
+        self.assertEqual(len(self.aggregator.progress_listeners), 1)
+
+    def test_register_progress_listener_fail(self):
+        """Check that register listener fails with not Callable objects."""
+        self.assertRaises(TypeError,
+            self.aggregator.register_progress_listener, [])
+        self.assertEqual(len(self.aggregator.progress_listeners), 0)
+
     def assertMiscCommandQueued(self, fc):
         """Assert that some command was queued."""
         self.assertEqual(len(self.aggregator.to_do), 1)
@@ -1308,6 +1396,15 @@ class StatusAggregatorTestCase(TestCase):
         self.assertEqual(
             {(fc.share_id, fc.node_id): (fc.deflated_size)},
             self.aggregator.progress)
+        self.assertEqual(len(self.aggregator.recent_transfers), 1)
+
+    def test_max_recent_files(self):
+        """Check that the queue doesn't exceed the 5 items."""
+        for i in range(15):
+            fc = FakeCommand()
+            self.status_frontend.upload_started(fc)
+            self.status_frontend.upload_finished(fc)
+        self.assertEqual(len(self.aggregator.recent_transfers), 5)
 
     def test_progress_made(self):
         """Progress on up and downloads is tracked."""
