@@ -36,11 +36,10 @@ import os
 from ConfigParser import ConfigParser
 from twisted.internet import defer
 from twisted.trial.unittest import TestCase
-from ubuntu_sso.xdg_base_directory import (
+from dirspec.basedir import (
     xdg_data_home,
     xdg_cache_home,
 )
-from ubuntuone.devtools.testcases import skipIfOS
 
 from contrib.testing.testcase import BaseTwistedTestCase
 from ubuntuone import platform
@@ -504,7 +503,6 @@ class TestConfigBasic(BaseTwistedTestCase):
 class UnicodePathsTestCase(TestCase):
     """Tests for unicode paths."""
 
-    @skipIfOS('linux2', 'On linux paths are bytes so this test does not apply')
     def test_get_config_files_path_encoding(self):
         """Check that get_config_files uses paths in the right encoding."""
         temp = self.mktemp()
@@ -562,7 +560,7 @@ class XdgHomeParsersTests(BaseTwistedTestCase):
     def test_good_value(self):
         """Test the parser using a good value."""
         homedir = os.path.join('', 'home', 'fake')
-        self.patch(platform, 'xdg_home', homedir)
+        self.patch(platform, 'user_home', homedir)
         expected = os.path.join(self.xdg_dir, 'hola', 'mundo')
         actual = self.parser(self.good_value)
         self.assertEqual(expected, actual)
@@ -702,6 +700,19 @@ class SyncDaemonConfigParserTests(BaseTwistedTestCase):
         self.assertEquals(self.cp.get('__main__', 'ignore').value,
                           ['.*\\.pyc', '.*\\.sw[opnx]'])
 
+    def test_fs_monitor_not_default(self):
+        """Test get monitor."""
+        monitor_id = 'my_monitor'
+        conf_file = os.path.join(self.test_root, 'test_new_config.conf')
+        with open_file(conf_file, 'w') as fd:
+            fd.write('[__main__]\n')
+            fd.write('fs_monitor = %s\n' % monitor_id)
+        self.assertTrue(path_exists(conf_file))
+        self.cp.read([conf_file])
+        self.cp.parse_all()
+        self.assertEquals(self.cp.get('__main__', 'fs_monitor').value,
+                monitor_id)
+
     def test_use_trash_default(self):
         """Test default configuration for use_trash."""
         self.cp.parse_all()
