@@ -37,6 +37,7 @@ from twisted.internet import defer
 from twisted.trial.unittest import TestCase
 
 from contrib.testing.testcase import BaseTwistedTestCase, FakeVolumeManager
+from ubuntuone.platform.filesystem_notifications.monitor import FilesystemMonitor
 from ubuntuone.syncdaemon import (
     event_queue,
     filesystem_manager,
@@ -406,6 +407,22 @@ class FakeMonitor(object):
         return self.shutdown_d
 
 
+class EventQueueInitTestCase(TestCase):
+    """Test the init of the EQ."""
+
+    def test_default_monitor(self):
+        """Test the init with the default monitor."""
+        eq = event_queue.EventQueue(None)
+        self.assertIsInstance(eq.monitor, FilesystemMonitor)
+        return eq.shutdown()
+
+    def test_passed_monitor(self):
+        """Test the init with a custom monitor."""
+        eq = event_queue.EventQueue(None, monitor_class=FakeMonitor)
+        self.assertIsInstance(eq.monitor, FakeMonitor)
+
+
+
 class EventQueueShutdownTestCase(TestCase):
     """Test the shutdown method in EQ."""
 
