@@ -1226,18 +1226,19 @@ class SyncdaemonEventListenerTestCase(BaseTestCase):
         self.addCleanup(self.main.event_q.unsubscribe, self.sd_obj)
 
 
-class DownloadTestCase(SyncdaemonEventListenerTestCase):
-    """Test the Download events in SyncdaemonEventListener."""
+class UploadTestCase(SyncdaemonEventListenerTestCase):
+    """Test the Upload events in SyncdaemonEventListener."""
 
     add_fsm_key = True
-    direction = 'Download'
-    bytes_key = 'n_bytes_read'
-    hash_kwarg = 'server_hash'
-    extra_finished_args = {}
+    direction = 'Upload'
+    bytes_key = 'n_bytes_written'
+    hash_kwarg = 'hash'
+    extra_finished_args = dict(new_generation='new_generation', hash='')
+    finished_event = 'AQ_UPLOAD_FINISHED'
 
     @defer.inlineCallbacks
     def setUp(self):
-        yield super(DownloadTestCase, self).setUp()
+        yield super(UploadTestCase, self).setUp()
         self.deferred = None
         self.signal_name = None
         if self.add_fsm_key:
@@ -1304,7 +1305,7 @@ class DownloadTestCase(SyncdaemonEventListenerTestCase):
         return self.deferred
 
     def test_handle_finished(self):
-        """Test the handle_AQ_<direction>_FINISHED method."""
+        """Test the handle_<finished_event> method."""
         self.signal_name = self.direction + 'Finished'
         self.deferred = defer.Deferred()
 
@@ -1320,10 +1321,9 @@ class DownloadTestCase(SyncdaemonEventListenerTestCase):
             self.patch(self.sd_obj.interface.status, 'SignalError',
                        self.error_handler)
 
-        kwargs = {'share_id': '', 'node_id': 'node_id', self.hash_kwarg: ''}
+        kwargs = {'share_id': '', 'node_id': 'node_id'}
         kwargs.update(self.extra_finished_args)
-        self.main.event_q.push('AQ_%s_FINISHED' % self.direction.upper(),
-                               **kwargs)
+        self.main.event_q.push(self.finished_event, **kwargs)
         return self.deferred
 
     def test_handle_event_error(self):
@@ -1350,21 +1350,29 @@ class DownloadTestCase(SyncdaemonEventListenerTestCase):
         return self.deferred
 
 
+class DownloadTestCase(UploadTestCase):
+    """Test the Download events in SyncdaemonEventListener."""
+
+    direction = 'Download'
+    bytes_key = 'n_bytes_read'
+    hash_kwarg = 'server_hash'
+    extra_finished_args = {}
+    finished_event = 'FSM_PARTIAL_COMMITED'
+
+    # The download is special, because we don't want to throw the ipc signal on
+    # AQ_DOWNLOAD_FINISHED but instead we should wait for FSM_PARTIAL_COMMITED
+
+    def test_ignore_pre_partial_commit_event(self):
+        """The AQ_DOWNLOAD_FINISHED signal is ignored."""
+        self.assertNotIn("handle_AQ_DOWNLOAD_FINISHED", vars(self.sd_class))
+
+
 class DownloadNoKeyTestCase(DownloadTestCase):
     """Test the Download events when there is a fsm KeyError."""
 
     add_fsm_key = False
 
 
-class UploadTestCase(DownloadTestCase):
-    """Test the Upload events in SyncdaemonEventListener."""
-
-    direction = 'Upload'
-    bytes_key = 'n_bytes_written'
-    hash_kwarg = 'hash'
-    extra_finished_args = dict(new_generation='new_generation')
-
-
 class UploadNoKeyTestCase(UploadTestCase):
     """Test the Upload events when there is a fsm KeyError."""
 
