@@ -65,6 +65,10 @@ class FakedExternalInterface(object):
         self.connect = lambda *a, **kw: self._called.append(('connect', a, kw))
         self.shutdown = lambda *a, **kw: None
 
+    def start(self):
+        """Do nothing."""
+        return defer.succeed(None)
+
 
 class MainTests(BaseTwistedTestCase):
     """ Basic tests to check main.Main """
@@ -278,7 +282,7 @@ class MainTests(BaseTwistedTestCase):
 
     def test_get_homedir(self):
         """The get_homedir returns the root dir."""
-        self.patch(main_mod, "xdg_home", self.home_dir)
+        self.patch(main_mod, "user_home", self.home_dir)
         expected = expand_user('~')
         main = self.build_main()
         self.assertEqual(main.get_homedir(), expected)
