@@ -84,7 +84,7 @@ def listen_for(event_q, event, callback, count=1, collect=False):
                     callback(args)
 
     listener = Listener()
-    setattr(listener, 'handle_'+event, listener._handle_event)
+    setattr(listener, 'handle_' + event, listener._handle_event)
     event_q.subscribe(listener)
     return listener
 
@@ -92,7 +92,7 @@ def listen_for(event_q, event, callback, count=1, collect=False):
 class FakeStatusFrontend(object):
     """A fake status frontend."""
 
-    def __init__(self):
+    def __init__(self, *args, **kwargs):
         """Initialize this instance."""
         self.call_log = []
 
