@@ -387,20 +387,29 @@ class TestSync(BaseSync):
         self.sync._handle_SV_HASH_NEW(mdobj.share_id, mdobj.node_id, '')
         self.assertTrue(self.called)
 
-    def test_SV_HASH_NEW_with_file_uploadinterrupted_coverage(self):
-        """A SV_HASH_NEW is received after upload interrupted."""
+    def test_SV_HASH_NEW_with_special_hash(self):
+        """A SV_HASH_NEW is received with hash in None, don't care state."""
         self.called = False
 
-        # create a file and put it in local, without server_hash, as
-        # if the upload was cut in the middle after the make file
+        def fake_meth(_, event, params, hash):
+            """Wrap SSMR.reput_file_from_local to test."""
+            self.assertEqual(event, 'SV_HASH_NEW')
+            self.assertEqual(hash, '')
+            self.called = True
+        self.patch(SyncStateMachineRunner, 'reput_file_from_local', fake_meth)
+
+        # create a file and leave it as NONE state
         somepath = os.path.join(self.root, 'somepath')
         mdid = self.fsm.create(somepath, '', node_id='node_id')
-        self.fsm.set_by_mdid(mdid, local_hash='somehash', crc32='crc32',
-                             stat='stat', size='size')
+        self.fsm.set_by_mdid(mdid, local_hash='somehsh', server_hash='somehsh',
+                             crc32='crc32', stat='stat', size='size')
 
         # send the event with no content and check
         mdobj = self.fsm.get_by_mdid(mdid)
         self.sync._handle_SV_HASH_NEW(mdobj.share_id, mdobj.node_id, '')
+        self.assertTrue(self.called)
+        mdobj = self.fsm.get_by_mdid(mdid)
+        self.assertEqual(mdobj.server_hash, '')
 
     def test_AQ_FILE_NEW_OK_with_md_in_none(self):
         """Created the file, and MD says it's in NONE."""
@@ -991,7 +1000,6 @@ class SyncStateMachineRunnerTestCase(BaseSync):
         with self._test_putcontent_upload_id(with_upload_id=False):
             self.ssmr.reput_file_from_local("SV_HASH_NEW", None, '')
 
-
     def test_commit_file_without_partial(self):
         """The .partial is lost when commiting the file."""
         # create the partial correctly, and break it!
@@ -1631,9 +1639,10 @@ class TestSyncDelta(BaseSync):
         self.main.fs.set_by_mdid(node.mdid, generation=dt.generation)
         return node
 
-    def create_dir(self):
+    def create_dir(self, dt=None):
         """Create a directory based on self.dirdelta."""
-        dt = self.dirdelta
+        if dt is None:
+            dt = self.dirdelta
         mdobj = self.main.fs.get_by_node_id(dt.share_id, dt.parent_id)
         path = os.path.join(
             self.main.fs.get_abspath(dt.share_id, mdobj.path),
@@ -2090,6 +2099,137 @@ class TestHandleAqRescanFromScratchOk(TestSyncDelta):
             (ROOT, self.dirdelta.node_id, True)])
 
 
+class TestChunkedRescanFromScratchOk(TestHandleAqRescanFromScratchOk):
+
+    def test_change_in_the_middle(self):
+        """Chunked delta handling with a change in the middle."""
+        directories = [self.rootdt]
+        files = []
+        for i in range(1,5):
+            d = delta.FileInfoDelta(
+                generation=i, is_live=True, file_type=delta.DIRECTORY,
+                parent_id=self.root_id, share_id=ROOT, node_id=uuid.uuid4(),
+                name=u"directory_ñ_%d" % i, is_public=False,
+                content_hash="hash", crc32=i, size=10, last_modified=0)
+            directories.append(d)
+            self.create_dir(dt=d)
+        for i in range(6, 10):
+            f = delta.FileInfoDelta(
+                generation=i, is_live=True, file_type=delta.FILE,
+                parent_id=self.root_id, share_id=ROOT, node_id=uuid.uuid4(),
+                name=u"fileñ.%d.txt" % i, is_public=False, content_hash="hash",
+                crc32=i, size=10, last_modified=0)
+            f.parent_id = directories[i-5].node_id
+            self.create_filetxt(dt=f)
+            files.append(f)
+
+        called = []
+        orig__handle_SV_FILE_DELETED = self.sync._handle_SV_FILE_DELETED
+        self.sync._handle_SV_FILE_DELETED = \
+                self.sync._handle_SV_FILE_DELETED = \
+                lambda *args: called.append(args)
+
+        # build a delta with files[3] node missing, caused by a change by other
+        # client while building the delta
+        fake_delta = directories + files[0:2] + files[3:5]
+        self.sync.handle_AQ_RESCAN_FROM_SCRATCH_OK(ROOT,
+            fake_delta, files[-1].generation, 100)
+
+        self.assertEqual(called, [
+            (ROOT, files[2].node_id, False)])
+
+        # call the real delete method.
+        orig__handle_SV_FILE_DELETED(*called[0])
+
+        # now fake the get_delta for the changed node that was missing in the
+        # rescan_from_scratch
+        changed_file = files[2]
+        changed_file.generation = files[-1].generation+1
+        changed_file.hash = "hash-1"
+
+        called = []
+        self.sync._handle_SV_FILE_DELETED = \
+            lambda *args: called.append(("delete",)+args)
+        self.sync._handle_SV_MOVED = \
+            lambda *args: called.append(("move",)+args)
+        self.sync._handle_SV_HASH_NEW = \
+            lambda *args: called.append(("new_hash",)+args)
+        self.sync._handle_SV_FILE_NEW = \
+            lambda *args: called.append(("new_file",)+args)
+        self.sync._handle_SV_DIR_NEW = \
+            lambda *args: called.append(("new_dir",)+args)
+
+        self.sync.handle_AQ_DELTA_OK(ROOT,
+            [changed_file], changed_file.generation, True, 100)
+        self.assertEqual(called, [
+            ("new_file", ROOT, changed_file.node_id, changed_file.parent_id,
+             changed_file.name.encode("utf-8"))])
+
+    def test_move_in_the_middle(self):
+        """Chunked delta handling with a move in the middle."""
+        directories = [self.rootdt]
+        files = []
+        for i in range(1,5):
+            d = delta.FileInfoDelta(
+                generation=i, is_live=True, file_type=delta.DIRECTORY,
+                parent_id=self.root_id, share_id=ROOT, node_id=uuid.uuid4(),
+                name=u"directory_ñ_%d" % i, is_public=False,
+                content_hash="hash", crc32=i, size=10, last_modified=0)
+            directories.append(d)
+            self.create_dir(dt=d)
+        for i in range(6, 10):
+            f = delta.FileInfoDelta(
+                generation=i, is_live=True, file_type=delta.FILE,
+                parent_id=self.root_id, share_id=ROOT, node_id=uuid.uuid4(),
+                name=u"fileñ.%d.txt" % i, is_public=False, content_hash="hash",
+                crc32=i, size=10, last_modified=0)
+            f.parent_id = directories[i-5].node_id
+            self.create_filetxt(dt=f)
+            files.append(f)
+
+        called = []
+        orig__handle_SV_FILE_DELETED = self.sync._handle_SV_FILE_DELETED
+        self.sync._handle_SV_FILE_DELETED = \
+                self.sync._handle_SV_FILE_DELETED = \
+                lambda *args: called.append(args)
+
+        # build a delta with files[3] node missing, caused by a change by other
+        # client while building the delta
+        fake_delta = directories + files[0:2] + files[3:5]
+        self.sync.handle_AQ_RESCAN_FROM_SCRATCH_OK(ROOT,
+            fake_delta, files[-1].generation, 100)
+
+        self.assertEqual(called, [
+            (ROOT, files[2].node_id, False)])
+
+        # call the real delete method.
+        orig__handle_SV_FILE_DELETED(*called[0])
+
+        # now fake the get_delta for the moved node that was missing in the
+        # rescan_from_scratch
+        changed_file = files[2]
+        changed_file.generation = files[-1].generation+1
+        changed_file.parent_id = directories[1].node_id
+
+        called = []
+        self.sync._handle_SV_FILE_DELETED = \
+            lambda *args: called.append(("delete",)+args)
+        self.sync._handle_SV_MOVED = \
+            lambda *args: called.append(("move",)+args)
+        self.sync._handle_SV_HASH_NEW = \
+            lambda *args: called.append(("new_hash",)+args)
+        self.sync._handle_SV_FILE_NEW = \
+            lambda *args: called.append(("new_file",)+args)
+        self.sync._handle_SV_DIR_NEW = \
+            lambda *args: called.append(("new_dir",)+args)
+
+        self.sync.handle_AQ_DELTA_OK(ROOT,
+            [changed_file], changed_file.generation, True, 100)
+        self.assertEqual(called, [
+            ("new_file", ROOT, changed_file.node_id, changed_file.parent_id,
+             changed_file.name.encode("utf-8"))])
+
+
 class TestSyncEvents(TestSyncDelta):
     """Testing sync stuff related to events."""
 
