@@ -2,7 +2,7 @@
 #
 # Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
 #
-# Copyright 2010 Canonical Ltd.
+# Copyright 2010-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,7 +15,21 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """Ubuntuone client logging utilities and config. """
+
 from __future__ import with_statement
 
 import contextlib
@@ -35,7 +49,7 @@ TRACE = 5
 NOTE = logging.ERROR - 1
 
 # map names to the extra levels
-levels = {'TRACE':TRACE, 'NOTE':NOTE}
+levels = {'TRACE': TRACE, 'NOTE': NOTE}
 for k, v in levels.items():
     logging.addLevelName(v, k)
 
@@ -98,7 +112,8 @@ class DayRotatingFileHandler(TimedRotatingFileHandler):
                 self.stream = self._open()
             if self.maxBytes > 0:                   # are we rolling over?
                 msg = "%s\n" % self.format(record)
-                self.stream.seek(0, 2)  #due to non-posix-compliant Windows feature
+                # due to non-posix-compliant Windows feature
+                self.stream.seek(0, 2)
                 if self.stream.tell() + len(msg) >= self.maxBytes:
                     return 1
             return 0
@@ -269,8 +284,6 @@ def log_call(log_func, with_args=True, with_result=True):
 
             if with_result:
                 log_func('%s: result %r.', f.__name__, res)
-            else:
-                log_func('%s: result %r.', f.__name__, '<hidden result>')
 
             return res
 
@@ -280,7 +293,7 @@ def log_call(log_func, with_args=True, with_result=True):
 
 
 ### configure the thing ###
-LOGBACKUP = 5 # the number of log files to keep around
+LOGBACKUP = 5  # the number of log files to keep around
 
 basic_formatter = logging.Formatter(fmt="%(asctime)s - %(name)s - " \
                                     "%(levelname)s - %(message)s")
