@@ -36,9 +36,9 @@ import warnings
 from twisted.internet import defer
 from ubuntuone.logger import log_call
 
-if sys.platform == 'win32':
-    from ubuntuone.platform.tools import windows
-    source = windows
+if sys.platform in ('win32', 'darwin'):
+    from ubuntuone.platform.tools import perspective_broker
+    source = perspective_broker
 else:
     from ubuntuone.platform.tools import linux
     source = linux
@@ -324,6 +324,13 @@ class SyncDaemonTool(object):
         self.log.debug('uploads: %r', uploads)
         defer.returnValue(uploads)
 
+    @defer.inlineCallbacks
+    @log_call(logger.debug)
+    def sync_menu(self):
+        """Return a deferred that will be fired with the sync menu data."""
+        results = yield self.proxy.call_method('status', 'sync_menu')
+        defer.returnValue(results)
+
     @defer.inlineCallbacks
     @log_call(logger.debug)
     def accept_share(self, share_id):
@@ -480,9 +487,9 @@ class SyncDaemonTool(object):
     def change_public_access(self, path, is_public):
         """Change the public access for a given path."""
         d = self.wait_for_signals(
-                'PublicAccessChanged', 'PublicAccessChangeError',
-                success_filter=lambda info: info['path'] == path,
-                error_filter=lambda info, _: info['path'] == path)
+            'PublicAccessChanged', 'PublicAccessChangeError',
+            success_filter=lambda info: info['path'] == path.decode('utf-8'),
+            error_filter=lambda info, _: info['path'] == path.decode('utf-8'))
 
         metadata = yield self.get_metadata(path)
         args = (metadata['share_id'], metadata['node_id'], is_public)
