@@ -33,7 +33,7 @@
 import itertools
 import operator
 import os
-
+from collections import deque, Callable
 
 import gettext
 
@@ -41,7 +41,10 @@ from twisted.internet import reactor, defer
 
 from ubuntuone.clientdefs import GETTEXT_PACKAGE
 from ubuntuone.status.logger import logger
-from ubuntuone.platform import session, notification
+from ubuntuone.platform import (
+    notification,
+    sync_menu
+)
 from ubuntuone.platform.messaging import Messaging
 from ubuntuone.platform.launcher import UbuntuOneLauncher, DummyLauncher
 
@@ -529,7 +532,6 @@ class ProgressBar(object):
     progress = 0.0
     updates_delay = 0.1
     timer = None
-    inhibitor_defer = None
 
     def __init__(self, clock=reactor):
         """Initialize this instance."""
@@ -559,9 +561,6 @@ class ProgressBar(object):
             self.visible = True
             self.launcher.show_progressbar()
             logger.debug("progressbar shown")
-            if self.inhibitor_defer is None:
-                self.inhibitor_defer = session.inhibit_logout_suspend(
-                                                         FILE_SYNC_IN_PROGRESS)
         if not self.timer:
             self.timer = Timer(self.updates_delay, clock=self.clock)
             self.timer.addCallback(self._timeout)
@@ -572,14 +571,6 @@ class ProgressBar(object):
         self.visible = False
         self.launcher.hide_progressbar()
         logger.debug("progressbar hidden")
-        if self.inhibitor_defer is not None:
-
-            def inhibitor_callback(inhibitor):
-                """The inhibitor was found, so cancel it."""
-                self.inhibitor_defer = None
-                return inhibitor.cancel()
-
-            self.inhibitor_defer.addCallback(inhibitor_callback)
 
 
 class FinalStatusBubble(object):
@@ -624,6 +615,8 @@ class StatusAggregator(object):
         self.finished_delay = 10
         self.progress = {}
         self.to_do = {}
+        self.recent_transfers = deque(maxlen=5)
+        self.progress_listeners = []
 
     def get_notification(self):
         """Create a new toggleable notification object."""
@@ -654,6 +647,13 @@ class StatusAggregator(object):
         self.to_do = {}
     # pylint: enable=W0201
 
+    def register_progress_listener(self, listener):
+        """Register a callable object to be notified."""
+        if isinstance(listener, Callable):
+            self.progress_listeners.append(listener)
+        else:
+            raise TypeError("Callable object expected.")
+
     def get_discovery_message(self):
         """Get the text for the discovery bubble."""
         lines = []
@@ -715,6 +715,8 @@ class StatusAggregator(object):
             progress = float(
                 sum(self.progress.values())) / sum(self.to_do.values())
             self.progress_bar.set_progress(progress)
+        for listener in self.progress_listeners:
+            listener()
 
     def download_started(self, command):
         """A download just started."""
@@ -775,6 +777,7 @@ class StatusAggregator(object):
         if command.deflated_size is not None:
             self.progress[
                 (command.share_id, command.node_id)] = command.deflated_size
+        self.recent_transfers.append(command.path)
         logger.debug("unqueueing command: %s", command.__class__.__name__)
         self.update_progressbar()
 
@@ -799,13 +802,38 @@ class StatusAggregator(object):
 class StatusFrontend(object):
     """Frontend for the status aggregator, used by the StatusListener."""
 
-    def __init__(self, clock=reactor):
+    def __init__(self, clock=reactor, service=None):
         """Initialize this instance."""
         self.aggregator = StatusAggregator(clock=clock)
         self.notification = self.aggregator.get_notification()
         self.messaging = Messaging()
         self.quota_timer = None
 
+        self.syncdaemon_service = service
+        self.sync_menu = None
+        self.start_sync_menu()
+
+    def start_sync_menu(self):
+        """Create the sync menu and register the progress listener."""
+        if self.syncdaemon_service is not None:
+            self.sync_menu = sync_menu.UbuntuOneSyncMenu(self,
+                self.syncdaemon_service)
+            self.aggregator.register_progress_listener(
+                self.sync_menu.update_transfers)
+
+    def recent_transfers(self):
+        """Return a tuple with the recent transfers paths."""
+        return list(self.aggregator.recent_transfers)
+
+    def files_uploading(self):
+        """Return a list with the files being uploading."""
+        uploading = []
+        for upload in self.aggregator.files_uploading:
+            if upload.size != 0:
+                uploading.append((upload.path, upload.size,
+                    upload.n_bytes_written))
+        return uploading
+
     def file_published(self, public_url):
         """A file was published."""
         status_event = FilePublishingStatus(new_public_url=public_url)
