@@ -36,13 +36,13 @@ import logging
 
 from ConfigParser import NoOptionError, NoSectionError
 from optparse import OptionParser
-from ubuntu_sso.xdg_base_directory import (
+from dirspec.basedir import (
     load_config_paths,
-    native_path,
     save_config_path,
     xdg_data_home,
     xdg_cache_home,
 )
+from dirspec.utils import unicode_path
 
 from ubuntuone.platform import expand_user
 
@@ -83,7 +83,7 @@ MAIN = '__main__'
 logger = logging.getLogger('ubuntuone.SyncDaemon.config')
 
 # get (and possibly create if don't exists) the user config file
-_user_config_path = os.path.join(native_path(save_config_path('ubuntuone')),
+_user_config_path = os.path.join(save_config_path('ubuntuone'),
                                  CONFIG_FILE)
 
 # module private config instance.
@@ -166,7 +166,7 @@ def get_config_files():
     """
     config_files = []
     for xdg_config_dir in load_config_paths('ubuntuone'):
-        xdg_config_dir = native_path(xdg_config_dir)
+        xdg_config_dir = unicode_path(xdg_config_dir)
         config_file = os.path.join(xdg_config_dir, CONFIG_FILE)
         if os.path.exists(config_file):
             config_files.append(config_file)
