@@ -744,6 +744,7 @@ class FileSystemManager(object):
                 mdobj = self.fs[mdid]
                 if mdobj["share_id"] == share_id:
                     all_mdobjs.append(_MDObject(**mdobj))
+
         return all_mdobjs
 
     def get_mdobjs_in_dir(self, base_path):
@@ -1141,7 +1142,7 @@ class FileSystemManager(object):
         return fd
 
     def commit_partial(self, node_id, share_id, local_hash):
-        """Create a .partial in disk and set the flag in metadata."""
+        """Commit a file from a .partial to disk."""
         mdid = self._idx_node_id[(share_id, node_id)]
         mdobj = self.fs[mdid]
         if mdobj["is_dir"]:
@@ -1165,6 +1166,8 @@ class FileSystemManager(object):
         mdobj["info"]["is_partial"] = False
         mdobj["stat"] = get_stat(path)
         self.fs[mdid] = mdobj
+        self.eq.push("FSM_PARTIAL_COMMITED", share_id=share_id,
+                     node_id=node_id)
 
     def remove_partial(self, node_id, share_id):
         """Remove a .partial in disk and set the flag in metadata."""
