@@ -1,8 +1,6 @@
 # ubuntuone.syncdaemon.logger - logging utilities
 #
-# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
-#
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,7 +13,21 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """ SyncDaemon logging utilities and config. """
+
 from __future__ import with_statement
 
 import logging
@@ -31,7 +43,7 @@ from ubuntuone.logger import (
     Logger,
     MultiFilter,
 )
-from ubuntuone.platform.xdg_base_directory import ubuntuone_log_dir
+from ubuntuone.platform.logger import ubuntuone_log_dir
 # api compatibility imports
 from ubuntuone import logger
 from ubuntuone.platform import get_filesystem_logger, setup_filesystem_logging
@@ -47,6 +59,7 @@ class mklog(object):
     called from, in order to make more informative messages.
     """
     __slots__ = ('logger', 'zipped_desc')
+
     def __init__(self, _logger, _method, _share, _uid, *args, **kwargs):
         # args are _-prepended to lower the chances of them
         # conflicting with kwargs
@@ -54,8 +67,7 @@ class mklog(object):
         all_args = []
         for arg in args:
             all_args.append(
-                repr(arg).decode('ascii', 'replace').encode('ascii', 'replace')
-                )
+              repr(arg).decode('ascii', 'replace').encode('ascii', 'replace'))
         for k, v in kwargs.items():
             v = repr(v).decode('ascii', 'replace').encode('ascii', 'replace')
             all_args.append("%s=%r" % (k, v))
@@ -63,6 +75,7 @@ class mklog(object):
 
         desc = "%-28s share:%-40r node:%-40r %s(%s) " % (_method, _share,
                                                          _uid, _method, args)
+        desc = desc.replace('%', '%%')
         self.zipped_desc = zlib.compress(desc, 9)
         self.logger = _logger
 
@@ -116,6 +129,7 @@ class mklog(object):
                 success_arg = success_arg(arg)
             self.debug(success_message, success_arg)
             return arg
+
         def errback(failure):
             "it failed!"
             self.error(failure_message, failure.getErrorMessage())
@@ -126,8 +140,10 @@ class mklog(object):
 # pylint: enable=C0103
 LOGFILENAME = os.path.join(ubuntuone_log_dir, 'syncdaemon.log')
 EXLOGFILENAME = os.path.join(ubuntuone_log_dir, 'syncdaemon-exceptions.log')
-INVALIDLOGFILENAME = os.path.join(ubuntuone_log_dir, 'syncdaemon-invalid-names.log')
-BROKENLOGFILENAME = os.path.join(ubuntuone_log_dir, 'syncdaemon-broken-nodes.log')
+INVALIDLOGFILENAME = os.path.join(ubuntuone_log_dir,
+    'syncdaemon-invalid-names.log')
+BROKENLOGFILENAME = os.path.join(ubuntuone_log_dir,
+    'syncdaemon-broken-nodes.log')
 
 
 root_logger = logging.getLogger("ubuntuone.SyncDaemon")
@@ -140,6 +156,7 @@ logging.setLoggerClass(Logger)
 root_handler = CustomRotatingFileHandler(filename=LOGFILENAME)
 exception_handler = CustomRotatingFileHandler(filename=EXLOGFILENAME)
 
+
 def init():
     # root logger
     root_logger.propagate = False
@@ -192,16 +209,19 @@ def configure_logging(level, maxBytes, backupCount):
     set_max_bytes(maxBytes)
     set_backup_count(backupCount)
 
+
 def set_level(level):
     """set 'level' as the level for all the logger/handlers"""
     root_logger.setLevel(level)
     root_handler.setLevel(level)
 
+
 def set_max_bytes(size):
     """set the maxBytes value in all the handlers"""
     root_handler.maxBytes = size
     exception_handler.maxBytes = size
 
+
 def set_backup_count(count):
     """set the backup count in all the handlers"""
     root_handler.backupCount = count
@@ -216,7 +236,7 @@ def set_debug(dest):
     @param dest: a string with a one or more of 'file', 'stdout', and 'stderr'
                  e.g. 'file stdout'
     """
-    if not [ v for v in ['file', 'stdout', 'stderr'] if v in dest]:
+    if not [v for v in ['file', 'stdout', 'stderr'] if v in dest]:
         # invalid dest value, let the loggers alone
         return
     sd_filter = MultiFilter(['ubuntuone.SyncDaemon', 'twisted', 'pyinotify'])
@@ -252,27 +272,27 @@ def set_server_debug(dest):
     @param dest: a string containing 'file' and/or 'stdout', e.g: 'file stdout'
     """
     logger = logging.getLogger("storage.server")
-    logger.setLevel(5) # this shows server messages
+    logger.setLevel(5)  # this shows server messages
     if 'file' in dest:
         filename = os.path.join(ubuntuone_log_dir, 'syncdaemon-debug.log')
         handler = DayRotatingFileHandler(filename=filename)
         handler.setFormatter(basic_formatter)
-        handler.setLevel(5) # this shows server messages
+        handler.setLevel(5)  # this shows server messages
         logger.addHandler(handler)
     if 'stdout' in dest:
         stdout_handler = logging.StreamHandler(sys.stdout)
         stdout_handler.setFormatter(basic_formatter)
-        stdout_handler.setLevel(5) # this shows server messages
+        stdout_handler.setLevel(5)  # this shows server messages
         logger.addHandler(stdout_handler)
     if 'stderrt' in dest:
         stdout_handler = logging.StreamHandler(sys.stdout)
         stdout_handler.setFormatter(basic_formatter)
-        stdout_handler.setLevel(5) # this shows server messages
+        stdout_handler.setLevel(5)  # this shows server messages
         logger.addHandler(stdout_handler)
 
 
 # if we are in debug mode, replace/add the handlers
-DEBUG = os.environ.get("DEBUG", None)
+DEBUG = os.environ.get("U1_DEBUG", None)
 if DEBUG:
     set_debug(DEBUG)
 
@@ -294,5 +314,3 @@ def rotate_logs():
         exception_handler.doRollover()
     except OSError:
         pass
-
-
