@@ -32,9 +32,9 @@ import logging
 import os
 import sys
 
+from dirspec.utils import user_home
 from twisted.internet import defer, reactor, task
 
-from ubuntu_sso.xdg_base_directory import native_path, xdg_home
 from ubuntuone.syncdaemon import (
     action_queue,
     config,
@@ -90,7 +90,8 @@ class Main(object):
                  handshake_timeout=30,
                  shares_symlink_name='Shared With Me',
                  read_limit=None, write_limit=None, throttling_enabled=False,
-                 ignore_files=None, oauth_credentials=None):
+                 ignore_files=None, oauth_credentials=None,
+                 monitor_class=None):
         self.root_dir = root_dir
         self.shares_dir = shares_dir
         self.shares_dir_link = os.path.join(self.root_dir, shares_symlink_name)
@@ -111,11 +112,12 @@ class Main(object):
         self.logger.info("Using %r as root dir", self.root_dir)
         self.logger.info("Using %r as data dir", self.data_dir)
         self.logger.info("Using %r as shares root dir", self.shares_dir)
-        self.db = tritcask.Tritcask(native_path(tritcask_dir))
+        self.db = tritcask.Tritcask(tritcask_dir)
         self.vm = volume_manager.VolumeManager(self)
         self.fs = filesystem_manager.FileSystemManager(
             data_dir, partials_dir, self.vm, self.db)
-        self.event_q = event_queue.EventQueue(self.fs, ignore_files)
+        self.event_q = event_queue.EventQueue(self.fs, ignore_files,
+                monitor_class=monitor_class)
         self.fs.register_eq(self.event_q)
 
         # subscribe VM to EQ, to be unsubscribed in shutdown
@@ -163,7 +165,8 @@ class Main(object):
 
     def start_status_listener(self):
         """Start the status listener if it is configured to start."""
-        self.status_listener = status_listener.get_listener(self.fs, self.vm)
+        self.status_listener = status_listener.get_listener(self.fs, self.vm,
+            self.external)
         # subscribe to EQ, to be unsubscribed in shutdown
         if self.status_listener:
             self.event_q.subscribe(self.status_listener)
@@ -216,6 +219,7 @@ class Main(object):
         """Setup the daemon to be ready to run."""
         # hook the event queue to the root dir
         self.event_q.push('SYS_INIT_DONE')
+        return self.external.start()
 
     @defer.inlineCallbacks
     def shutdown(self, with_restart=False):
@@ -265,7 +269,7 @@ class Main(object):
 
     def get_homedir(self):
         """Return the home dir point."""
-        return xdg_home
+        return user_home
 
     def get_rootdir(self):
         """Return the base dir/mount point."""
