@@ -1,8 +1,6 @@
-# ubuntuone.syncdaemon.sync - sync module
+# -*- coding: utf-8 -*-
 #
-# Author: Lucio Torre <lucio.torre@canonical.com>
-#
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -15,13 +13,26 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""This is the magic"""
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
+"""This is the magic."""
+
 from __future__ import with_statement
 
 import os
 import logging
 from operator import attrgetter
-from cStringIO import StringIO
 import sys
 
 from ubuntuone.syncdaemon.marker import MDMarker
@@ -41,6 +52,7 @@ from ubuntuone.platform import (
 
 empty_hash = ""
 
+
 class FSKey(object):
     """Encapsulate the problem of getting the metadata with different keys."""
     __slots__ = ('fs', 'keys', 'mdid', '_changes')
@@ -138,19 +150,6 @@ class FSKey(object):
         except KeyError:
             return 'NA'
 
-    def open_file(self):
-        """Get the file object for reading."""
-        mdid = self.get_mdid()
-        try:
-            fo = self.fs.open_file(mdid)
-        except IOError:
-            # this is a HUGE cheat
-            # the state expectes to start a download
-            # but the file is gone. so to keep the transitions correct
-            # we return an empty file. we will later receive the FS_DELETE
-            return StringIO()
-        return fo
-
     def upload_finished(self, server_hash):
         """Signal that we have uploaded the file."""
         mdid = self.get_mdid()
@@ -272,7 +271,7 @@ class FileLogger(object):
                 path = self.key.safe_get('path')
             extra = dict(message=message,
                          mdid=self.key.safe_get("mdid"),
-                         path=path,
+                         path=path.replace('%', '%%'),   # escape %
                          share_id=self.key.safe_get("share_id") or 'root',
                          node_id=self.key.safe_get("node_id"),
                          hasmd=self.key.has_metadata(),
@@ -289,7 +288,7 @@ class FileLogger(object):
             extra.update(self.key.keys)
         message = format % extra
         if lvl == -1:
-            kwargs.update({'exc_info':exc_info})
+            kwargs.update({'exc_info': exc_info})
             self.logger.error(message, *args, **kwargs)
         else:
             self.logger.log(lvl, message, *args, **kwargs)
@@ -415,9 +414,7 @@ class SyncStateMachineRunner(StateMachineRunner):
             self.log.info(m, new_generation, volume.generation, volume_id)
             self.m.action_q.get_delta(volume_id, volume.generation)
 
-
     # EVENT HANDLERS
-
     def nothing(self, event, params, *args):
         """pass"""
         pass
@@ -478,11 +475,8 @@ class SyncStateMachineRunner(StateMachineRunner):
         node_id = self.key['node_id']
         path = self.key['path']
         self.m.fs.create_partial(node_id=node_id, share_id=share_id)
-        factory = lambda: self.m.fs.get_partial_for_writing(node_id=node_id,
-                                                            share_id=share_id)
         self.m.action_q.download(share_id=share_id, node_id=node_id,
-                                 server_hash=hash, path=path,
-                                 fileobj_factory=factory)
+                                 server_hash=hash, path=path)
 
     def reget_file(self, event, params, hash):
         """cancel and reget this download."""
@@ -516,7 +510,6 @@ class SyncStateMachineRunner(StateMachineRunner):
         if not self.key.is_dir():
             self.m.hash_q.insert(self.key['path'], self.key['mdid'])
 
-
     def server_file_changed_back(self, event, params, hash):
         """cancel and dont reget this download."""
         self.key.set(server_hash=hash)
@@ -536,7 +529,6 @@ class SyncStateMachineRunner(StateMachineRunner):
             self.log.warning("Lost .partial when commiting node! volume_id=%r "
                              "node_id=%r", key['share_id'], key['node_id'])
 
-
     def new_local_file(self, event, parms, path):
         """a new local file was created"""
         parent_path = os.path.dirname(path)
@@ -597,10 +589,10 @@ class SyncStateMachineRunner(StateMachineRunner):
         """Starts the scan again on a dir."""
         self.m.lr.scan_dir(self.key['mdid'], self.key['path'], udfmode)
 
-    def reput_file_from_local(self, event, params, hash):
+    def reput_file_from_local(self, event, params, hash_value):
         """Re put the file from its local state."""
         self.m.action_q.cancel_upload(share_id=self.key['share_id'],
-                            node_id=self.key['node_id'])
+                                      node_id=self.key['node_id'])
 
         local_hash = self.key['local_hash']
         previous_hash = self.key['server_hash']
@@ -612,8 +604,7 @@ class SyncStateMachineRunner(StateMachineRunner):
         upload_id = self.key.get('upload_id')
 
         self.m.action_q.upload(share_id, node_id, previous_hash, local_hash,
-                               crc32, size, path, self.key.open_file,
-                               upload_id=upload_id)
+                               crc32, size, path, upload_id=upload_id)
 
     def put_file(self, event, params, hash, crc32, size, stat):
         """Upload the file to the server."""
@@ -625,9 +616,7 @@ class SyncStateMachineRunner(StateMachineRunner):
 
         self.m.action_q.upload(share_id=self.key['share_id'],
             node_id=self.key['node_id'], previous_hash=previous_hash,
-            hash=hash, crc32=crc32, size=size, path=path,
-            fileobj_factory=self.key.open_file, upload_id=upload_id)
-
+            hash=hash, crc32=crc32, size=size, path=path, upload_id=upload_id)
 
     def converges_to_server(self, event, params, hash, crc32, size, stat):
         """the local changes now match the server"""
@@ -646,7 +635,6 @@ class SyncStateMachineRunner(StateMachineRunner):
         self.key.sync()
         self.m.hash_q.insert(self.key['path'], self.key['mdid'])
 
-
     def reput_file(self, event, param, hash, crc32, size, stat):
         """Put the file again."""
         self.m.action_q.cancel_upload(share_id=self.key['share_id'],
@@ -659,8 +647,7 @@ class SyncStateMachineRunner(StateMachineRunner):
         self.key.sync()
         self.m.action_q.upload(share_id=self.key['share_id'],
             node_id=self.key['node_id'], previous_hash=previous_hash,
-            hash=hash, crc32=crc32, size=size, path=path,
-            fileobj_factory=self.key.open_file, upload_id=upload_id)
+            hash=hash, crc32=crc32, size=size, path=path, upload_id=upload_id)
 
     def server_file_now_matches(self, event, params, hash):
         """We got a server hash that matches local hash"""
@@ -854,7 +841,13 @@ class Sync(object):
         """on SV_HASH_NEW.  No longer called by EQ, only internally."""
         key = FSKey(self.m.fs, share_id=share_id, node_id=node_id)
         log = FileLogger(self.logger, key)
+
         ssmr = SyncStateMachineRunner(self.fsm, self.m, key, log)
+        if hash == "":
+            # Special case for hash == "", aka broken node.
+            # Set the server_hash = hash to force LOCAL state
+            key.set(server_hash=hash)
+            key.sync()
         ssmr.signal_event_with_hash("SV_HASH_NEW", hash)
 
     def _handle_SV_FILE_NEW(self, share_id, node_id, parent_id, name):
@@ -1161,7 +1154,7 @@ class Sync(object):
                 elif dt.file_type == delta.FILE:
                     is_dir = False
                 else:
-                    self.logger.warn("Unknown file type: %r" , dt.file_type)
+                    self.logger.warn("Unknown file type: %r", dt.file_type)
                     continue
 
                 # if the node is dead, call the remove handler and forget
@@ -1222,7 +1215,6 @@ class Sync(object):
                                          node_parent_id, dt.parent_id,
                                          node_name, dt_name)
 
-
                 # if its a dir, theres nothing else that we do with them except
                 # creating them.
                 # if its a file, we only care about the hash
@@ -1263,7 +1255,7 @@ class Sync(object):
             volume_id, len(delta_content))
 
         # remove root and apply the delta
-        new_delta_content = [ dt for dt in delta_content if dt.parent_id ]
+        new_delta_content = [dt for dt in delta_content if dt.parent_id]
 
         self.handle_AQ_DELTA_OK(volume_id, new_delta_content, end_generation,
                                 True, free_bytes)
